#
# spec file for package netcdf
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?sles_version}
%define _mvapich2 1
%endif
%if 0%{?suse_version}
%define _openmpi 1
%endif

%define _mpi %{?_openmpi:openmpi} %{?_mvapich2:mvapich2}

Name:           netcdf
%define libname libnetcdf
Summary:        Command-line programs for the NetCDF scientific data format
License:        NetCDF
Group:          Productivity/Scientific/Other
Version:        4.3.3.1
Release:        8.11
%define sonum   7
Url:            http://www.unidata.ucar.edu/software/netcdf/
Source:         ftp://ftp.unidata.ucar.edu/pub/%{name}/%{name}-%{version}.tar.gz
Source1:        nc-config.1.gz
Source2:        baselibs.conf
Patch0:         %{name}-correct_casting.patch
Patch1:         %{name}-codecleanup.patch
Patch2:         %{name}-no_date_time.patch
#Strip FFLAGS from nc-config
#Use pkgconfig in nc-config to avoid multi-lib issues
Patch3:         netcdf-pkgconfig.patch
#Strip FFLAGS from nc-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gawk
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf-devel
BuildRequires:  hdf5-devel >= 1.8.8
BuildRequires:  libcurl-devel >= 7.18.0
BuildRequires:  libhdf
BuildRequires:  libhdf5
BuildRequires:  libhdf5_hl
BuildRequires:  pkg-config
BuildRequires:  zlib-devel >= 1.2.5
%ifarch %ix86 x86_64 ppc ppc64 s390x armv7l
BuildRequires:  valgrind
%endif
%if 0%{?_openmpi}
BuildRequires:  hdf-openmpi-devel
BuildRequires:  hdf5-openmpi-devel
BuildRequires:  libhdf-openmpi
BuildRequires:  libhdf5-openmpi
BuildRequires:  libhdf5_hl-openmpi
BuildRequires:  libpnetcdf-openmpi
BuildRequires:  openmpi-devel
BuildRequires:  parallel-netcdf-openmpi-devel
%endif
%if 0%{?_mvapich2}
BuildRequires:  hdf-mvapich2-devel
BuildRequires:  hdf5-mvapich2-devel
BuildRequires:  libhdf-mvapich2
BuildRequires:  libhdf5-mvapich2
BuildRequires:  libhdf5_hl-mvapich2
BuildRequires:  libpnetcdf-mvapich2
BuildRequires:  mvapich2-devel
BuildRequires:  parallel-netcdf-mvapich2-devel
%endif
Requires:       %{libname}%{sonum} = %{version}

%description
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains utility functions for working with NetCDF files.

%package openmpi
Summary:        Command-line programs for the NetCDF scientific data format
Group:          Productivity/Scientific/Other
Requires:       %{libname}%{sonum}-openmpi = %{version}

%description openmpi
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the openmpi version of utility functions for
working with NetCDF files.

%package mvapich2
Summary:        Command-line programs for the NetCDF scientific data format
Group:          Productivity/Scientific/Other
Requires:       %{libname}%{sonum}-mvapich2 = %{version}

%description mvapich2
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the mvapich2 version of utility functions for
working with NetCDF files.

%package -n     %{libname}%{sonum}
Summary:        Shared libraries for the NetCDF scientific data format
Group:          Productivity/Scientific/Other
Provides:       %{libname}-4 = %{version}
Obsoletes:      %{libname}-4 < %{version}
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname} = %{version}
Obsoletes:      %{libname} < %{version}
Requires:       libhdf
Requires:       libhdf5
Requires:       libhdf5_hl

%description -n %{libname}%{sonum}
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the NetCDF runtime libraries.

%package -n     %{libname}%{sonum}-openmpi
Summary:        Shared libraries for the NetCDF scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname}-openmpi = %{version}
Obsoletes:      %{libname}-openmpi < %{version}
Requires:       libhdf-openmpi
Requires:       libhdf5-openmpi
Requires:       libhdf5_hl-openmpi
Requires:       libpnetcdf-openmpi

%description -n %{libname}%{sonum}-openmpi
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the openmpi versuib if the NetCDF runtime
libraries.

%package -n     %{libname}%{sonum}-mvapich2
Summary:        Shared libraries for the NetCDF scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname}-mvapich2 = %{version}
Obsoletes:      %{libname}-mvapich2 < %{version}
Requires:       libhdf-mvapich2
Requires:       libhdf5-mvapich2
Requires:       libhdf5_hl-mvapich2
Requires:       libpnetcdf-mvapich2

%description -n %{libname}%{sonum}-mvapich2
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the openmpi versuib if the NetCDF runtime
libraries.

%package devel-data
Summary:        Development data files for %{name}
Group:          Development/Libraries/C and C++

%description devel-data
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains generic files needed to create projects that use
any version of NetCDF.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{sonum} = %{version}
Requires:       %{name}-devel-data = %{version}
Requires:       hdf-devel
Requires:       hdf5-devel >= 1.8.8
Requires:       libcurl-devel >= 7.18.0
Requires:       pkgconfig
Requires:       zlib-devel >= 1.2.5

%description devel
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains all files needed to create projects that use NetCDF.

%package openmpi-devel
Summary:        Development files for %{name}-openmpi
Group:          Development/Libraries/Parallel
Requires:       %{libname}%{sonum}-openmpi = %{version}
Requires:       %{name}-devel-data = %{version}
Requires:       hdf-openmpi-devel
Requires:       hdf5-openmpi-devel >= 1.8.8
Requires:       libcurl-devel >= 7.18.0
Requires:       openmpi-devel
Requires:       parallel-netcdf-openmpi-devel
Requires:       pkgconfig
Requires:       zlib-devel >= 1.2.5

%description openmpi-devel
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains all files needed to create projects that use
the openmpi version of NetCDF.

%package mvapich2-devel
Summary:        Development files for %{name}-mvapich2
Group:          Development/Libraries/Parallel
Requires:       %{libname}%{sonum}-mvapich2 = %{version}
Requires:       %{name}-devel-data = %{version}
Requires:       hdf-mvapich2-devel
Requires:       hdf5-mvapich2-devel >= 1.8.8
Requires:       libcurl-devel >= 7.18.0
Requires:       mvapich2-devel
Requires:       parallel-netcdf-mvapich2-devel
Requires:       pkgconfig
Requires:       zlib-devel >= 1.2.5

%description mvapich2-devel
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains all files needed to create projects that use
the mvapich2 version of NetCDF.

%package devel-static
Summary:        Static development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       hdf-devel
Requires:       hdf5-devel >= 1.8.8
Requires:       libcurl-devel >= 7.18.0
Requires:       zlib-devel >= 1.2.5

%description devel-static
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the static libraries for NetCDF.

%package openmpi-devel-static
Summary:        Static development files for %{name}-openmpi
Group:          Development/Libraries/Parallel
Requires:       %{name}-openmpi-devel = %{version}

%description openmpi-devel-static
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the openmpi versions of the static libraries 
for NetCDF.

%package mvapich2-devel-static
Summary:        Static development files for %{name}-mvapich2
Group:          Development/Libraries/Parallel
Requires:       %{name}-mvapich2-devel = %{version}

%description mvapich2-devel-static
NetCDF is a set of software libraries and self-describing, 
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data.

NetCDF (network Common Data Form) is an interface for array-oriented
data access and a freely-distributed collection of software libraries
for C, Fortran, C++, and perl that provides an implementation of the
interface.  The NetCDF library also defines a machine-independent
format for representing scientific data.  Together, the interface,
library, and format support the creation, access, and sharing of
scientific data. The NetCDF software was developed at the Unidata
Program Center in Boulder, Colorado.

NetCDF data is:
   - Self-Describing: A NetCDF file includes information about the
     data it contains.
   - Network-transparent:  A NetCDF file is represented in a form that
     can be accessed by computers with different ways of storing
     integers, characters, and floating-point numbers.
   - Direct-access:  A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding
     data.
   - Appendable:  Data can be appended to a NetCDF dataset along one
     dimension without copying the dataset or redefining its
     structure. The structure of a NetCDF dataset can be changed,
     though this sometimes causes the dataset to be copied.
   - Sharable:  One writer and multiple readers may simultaneously
     access the same NetCDF file.

This package contains the mvapich2 versions of the static libraries 
for NetCDF.


%prep
%setup -q
%patch0 -p1 -b .correct_casting
%patch1 -p1 -b .codecleanup
%patch2 -p0 -b .no_date_time
%patch3 -p1 -b .pkgconfig

echo "prepare parallel builds: %_mpi"
for build_dir in build %_mpi; do
    mkdir $build_dir
    ln -s ../configure $build_dir
done

%build
pushd build
export CC=gcc CXX=g++ FC=gfortran
export CFLAGS="%{optflags} -fno-strict-aliasing" 
export CXXFLAGS="%{optflags}"
export FCFLAGS="%{optflags}"
%configure \
    --enable-shared \
    --enable-netcdf-4 \
    --enable-dap \
    --enable-ncgen4 \
    --enable-extra-example-tests \
    --disable-dap-remote-tests \
    --with-pic \
    --disable-doxygen \
    --enable-static \
    --enable-hdf4

make %{?_smp_mflags}
popd

for build_dir in %_mpi; do
pushd $build_dir
popd
done

%install
for build_dir in build; do
# for build_dir in %_mpi build; do
make install DESTDIR="%{buildroot}" -C "$build_dir"
done

mkdir -p %{buildroot}%{_mandir}/man1
install -m644 %{S:1} %{buildroot}%{_mandir}/man1
rm -f %{buildroot}%{_libdir}/*.la

# rpm macro for version checking
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/macros.netcdf <<EOF
#
# RPM macros for hdf5 packaging
#
%_netcdf_sonum  %{sonum}
%_netcdf_version  %{version}
EOF

%check
for build_dir in build; do
# for build_dir in %_mpi build; do
    make -C $build_dir check
done

%post -n %{libname}%{sonum} -p /sbin/ldconfig
%postun -n %{libname}%{sonum} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc COPYRIGHT README.md RELEASE_NOTES.md
%{_bindir}/*
%exclude %{_bindir}/nc-config
%{_mandir}/man1/*

%files -n %{libname}%{sonum}
%defattr(-,root,root,-)
%{_libdir}/libnetcdf.so.*
%{_libdir}/libnetcdf.settings

%files devel-data
%defattr(-,root,root,-)
%{_sysconfdir}/rpm/macros.netcdf

%files devel
%defattr(-,root,root,-)
%{_bindir}/nc-config
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/netcdf.pc
%{_mandir}/man3/*

%files devel-static
%defattr(-,root,root,-)
%{_libdir}/libnetcdf.a

%changelog
* Fri Sep 30 2016 jengelh@inai.de
- Add baselibs.conf for Leap 42.2+ so that ffmpeg-32bit works
* Mon Aug 24 2015 toddrme2178@gmail.com
- Currently the regular, openmpi, and mpivachi2 versions of the
  library packages all provide the exact same libraries.  So any
  package built against the -devel package will end up with an
  "unresolvable" build error because there are multiple versions
  of the library it can use. To avoid this, I have added generic
  provides for the library package so packages can depend on the
  version they really need, avoiding these build issues.
- Depend on the correct regular, openmpi, and mpivachi2 versions of
  hdf, hdf5, and parallel-netcdf.
* Mon Jul 27 2015 toddrme2178@gmail.com
- Update subpackage groups
- Make subpackage summaries and descriptions more consistent
- Provide rpm macros for version identification
- Spec file cleanups
- Build parallel versions of the library.
* Fri Jul 24 2015 toddrme2178@gmail.com
- Build with HDF4 support
* Sat Apr 18 2015 p.drouand@gmail.com
- Update to version 4.3.3.1
  * When the NC_MPIPOSIX flag is given for parallel I/O access and
    the HDF5 library does not have the MPI-POSIX VFD configured in,
    the NC_MPIPOSIX flag is transparently aliased to the NC_MPIIO
    flag within the netCDF-4 library.
  * DAP requests now always include a restraint. Due to a problem in
    version 4.3.2, no constraint was generated when all variables were
    requested.
  * Fixed the code for handling character constants in datalists in
    ncgen. Two of the problems were:
  - It failed on large constants
  - It did not handle e.g.
  - var = 'a', 'b', …
    in the same way that ncgen3 did.
- Changes from version 4.3.3
  * Fixed bug resulting in error closing a valid netCDF-4 file with
    a dimension and a non-coordinate variable with the same name.
    [NCF-324](https://bugtracking.unidata.ucar.edu/browse/NCF-324)
  * Enabled previously-disabled shell-script-based tests for Visual
    Studio when `bash` is detected.
- Update netcdf-no_date_time.patch
* Tue Sep  2 2014 coolo@suse.com
- fix license for spdx 1.2
* Thu May  1 2014 ocefpaf@gmail.com
- update to 4.3.2
  * Improved type handling with respect to fill-values.
  * Enabled netCDF-4 bit-for-bit reproducibility for nccopy and other
    applications (thanks to Rimvydas Jasinskas and Quincey Koziol).
  * Improved cmake build process.
  * As part of an ongoing project, the Doxygen-generated netCDF documentation
    has been reorganized. The goal is to make the documentation easier to
    parse, and to eliminate redundant material.
* Mon Feb 10 2014 opensuse@dstoecker.de
- update to 4.3.1.1
  * Corrected a DAP issue reported by Jeff Whitaker related to
    non-conforming servers.
  * Corrected an issue with DAP tests failing in a 64-bit Cygwin
    environment. NCF-286
  * Add an extended format inquiry method to the netcdf API:
    nc_inq_format_extended. NC_HAVE_INQ_FORMAT_EXTENDED is defined
    in netcdf.h NCF-273
  * Fixed fill value handling for string types in nc4_get_vara().
  * Corrected behavior of nc_inq_unlimdim and nv_inq_unlimdims to
    report dimids in same order as nc_inq_dimids.
  * A number of previously-disabled unit tests were reviewed and
    made active.
  * When opening a netCDF-4 file, streamline the iteration over
    objects in the underlying HDF5 file.
  * Fixed netCDF-4 failure when renaming a dimension and renaming
    a variable using that dimension, in either order. NCF-177
  * When compiling with hdf4 support, both autotools and cmake-based
    builds now properly look for the libjpeg dependency and will link
    against it when found (or complain if it's not). Also added
    ENABLE_HDF4_FILE_TESTS option to CMake-based builds.
  * Fixed bug in ncgen; it was not properly filling empty string
    constants ("") to be the proper length. NCF-279
  * Fixed bug in ncgen where it was interpreting int64 constants as
    uint64 constants. NCF-278
  * Fixed bug in handling Http Basic Authorization. The code was
    actually there but was not being executed. NCF-277
  * Added hack to the DAP code to address a problem with the
    Columbia.edu server. That server does not serve up proper DAP2 DDS
    replies. The Dataset {...} name changes depending on if the request
    has certain kinds of constraints. NCF-276
  * Fixed bugs with ncdump annotation of values, using -b or -f
    options. NCF-275
  * Added better documentation about accessing ESG datasets. See
    http://www.unidata.ucar.edu/software/netcdf/docs/esg.html.
  * Corrected an issue with CMake-based builds enabling HDF4 support
    where the HDF4 libraries were in a non-standard location.
  * Fix bug introduced by NCF-267 where octal constants above '\177'
    were not recognized as proper octal constants. NCF-271
  * Fixed an issue where the netcdf.3 man page was not being installed
    by CMake-based builds. Github
  * Modify ncgen to support NUL characters in character array
    constants. NCF-267
  * Modify ncgen to support disambiguating references to an enum
    constant in a data list. NCF-265
  * Corrected bug in netCDF-4 dimension ID ordering assumptions,
    resulting in access that works locally but fails through DAP
    server. NCF-166
  * Ensure netCDF-4 compiles with OpenMPI as an alternative to
    MPICH2. NCF-160
  * Addressed issue with hanging Parallel netCDF-4 using HDF5 1.8.10.
    NCF-240
  * Removed deprecated directories:
    librpc/
    udunits/
    libcf/
    libcdmr/
  * Added configure and accompanying configuration files/templates to
    release repository. These will only be added to tagged releases
    on GitHub.
  * Integrated a fix by Quincey Koziol which addressed a variation of
    NCF-250, Fix issue of netCDF-4 parallel independent access with
    unlimited dimension hanging.
  * Integrated change contributed by Orion Poplawski which integrated
    GNUInstallDirs into the netCDF-C CMake system; this will permit
    systems that install into lib64 (such as Fedora) to make install
    without problem.
  * Corrected an error with the CMake config files that resulted in the
    netcdf.3 manpage not being built or installed.
  * Added nc_rename_grp to allow for group renaming in netCDF-4 files. NCF-204
  * Added a NC_HAVE_RENAME_GRP macro to netcdf.h, as per a request by
    Charlie Zender. This will allow software compiling against netcdf
    to easily query whether or not nc_rename_grp() is available.
  * Added Greg Sjaardema's contributed optimization for the nc4_find_dim_len
    function in libsrc4/nc4internal.c. The patch eliminates several
    malloc/free calls that exist in the original coding.
  * Added support for dynamic loading, to compliment the dynamic loading
    support introduced in hdf 1.8.11. Dynamic loading support depends on
    libdl, and is enabled as follows: NCF-258
    autotools-based builds: –enable-dynamic-loading
    cmake-based builds: -DENABLE_DYNAMIC_LOADING=ON
  * Fix issue of netCDF-4 parallel independent access with unlimited
    dimension hanging. Extending the size of an unlimited dimension in
    HDF5 must be a collective operation, so now an error is returned if
    trying to extend in independent access mode. NCF-250
  * Fixed bug with netCDF-4's inability to read HDF5 scalar numeric
    attributes. Also allow, in addition to zero length strings, a new
    NULL pointer as a string value. to improve interoperability with
    HDF5. This required a new CDL constant, 'NIL', that can be output
    from ncdump for such a string value in an HDF5 or netCDF-4 file.
    The ncgen utility was also modified to properly handle such NIL
    values for strings. NCF-56
  * Fix contributed by Nath Gopalaswamy to large file problem reading
    netCDF classic or 64-bit offset files that have a UINT32_MAX flag
    for large last record size of a variable that has values larger than
    1 byte. This problem had previously been fixed for writing such data,
    but was only tested with an ncbyte variable.
  * Fixed various minor documentation problems.
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 4.3.0
  * fsync: Changed default in autotools config file; fsync must
    now be explicitely enabled instead of explicitely disabled.
  * Fixed netCDF-4 bug where odometer code for libdap2 mishandled
    stride > 1. Bug reported by Ansley Manke.
  * Fixed netCDF-4 bug where netCDF would ignore the HDF5 reference
    type in the file, instead of rejecting the file as it should.
  * Fixed netCDF-4 bug with particular order of creation of
    dimensions, coordinate variables, and subgroups resulting in
    two dimensions with the same dimension ID.
  * Fixed netCDF-4 bug with a multidimensional coordinate variable
    in a subgroup getting the wrong dimension IDs for its
    dimensions.
  * Fixed bug with incorrect fixed-size variable offsets in header
    getting written when schema changed for files created by
    parallel-netcdf. Thanks to Wei-keng Liao for developing and
    contributing the fix.
  * Fixed bug in handling old servers that do not do proper
    Grid to Structure conversions.
  * Replaced the oc library with oc2.0
  * Fix bug with nc_get_var1_uint() not accepting unsigned ints
    larger than 2**31.
  * Fix to convert occurrences of '/' in DAP names to %%2f.
  * Fix bug in netCDF-4 with scalar non-coordinate variables with
    same name as dimensions.
  * Fix bug in which calling netCDF-4 functions in which behavior
    that should not depend on order of calls sometimes produces
    the wrong results.
  * Merged in nccopy additions from Martin van Driel to support
  - g and -v options for specifying which groups or variables are
    to be copied.
  * Merged in parallel-netcdf bugs fixes from Greg Sjaardema.
  * Modify ncgen so that if the incoming file has a special
    attribute, then it is used to establish the special property of
    the netcdf file, but the attribute is not included as a real
    attribute in the file..
  * Added library version info to the user-agent string so that the
    server logs will be more informative.
  * Added work around for bad servers that sometimes sends DAP
    dataset with duplicate field names.
  * Fixed bug with strided access for NC_STRING type.
  * Prevented adding an invalid _FillValue attribute to a variable
    (with nonmatching type or multiple values), to avoid later
    error when any record variable is extended.
  * Fix bug in which some uses of vlen within compounds causes HDF5
    errors.
  * Fixed ncdump bug in display of data values of variables that use
    multiple unlimited dimensions.
  * Fix bug in which interspersing def_var calls with put_var calls
    can lead to corrupt metadata in a netCDF file with groups and
    inherited dimensions.
  * Building shared libraries works with DAP and netCDF4
    functionality.
  * 32-and-64-bit builds are working under MinGW on Windows.
  * Config.h for Windows compiles are included in the build.
  * NetCDF-4 dependency on NC_MAX_DIMS has been removed.
  * 64-bit DLL's are produced on Windows.
  * DLL Packaging issues are resolved.
  * The CMake build system (with related ctest and cdash systems
    for testing) has been integrated into netCDF-C. This allows for
    Visual Studio-based builds in addition to gcc-based builds.
    This requires at least CMake version 2.8.8. This
    replaces/supplements the cross-compiled set of Visual-Studio
    compatible netCDF libraries introduced in netCDF 4.2.1-rc1.
- Updated buildrequires versions.
* Tue Oct 16 2012 pth@suse.de
- Copy Changes from the release notes to here for the updates to 4.2.1
  and 4.2.1.1
* Sun Aug  5 2012 ocefpaf@gmail.com
- Update to 4.2.1.1:
  * Fix DAP performance bug remotely accessing large files (> 2GiB).
  * Properly escape special characters in CDL output from ncdump for
    netCDF-4 string data.
* Wed Jul 25 2012 ocefpaf@gmail.com
- Update to 4.2.1:
  * Add a specific NC_MMAP mode flag to modify behavior of NC_DISKLESS.
  * Changed the file protections for NC_DISKLESS created files to 0666.
  * Fixed ncdump to report error when an unsupported option is specified.
  * Fixed documentation of CDL char constants in Users Guide and ncgen
    man page.
  * Fixed memory leak detected by valgrind in one of the HDF5 tests.
  For further changes pleaase see the file RELEASE_NOTES in
  /usr/share/doc/packages/netcdf
* Thu Apr 26 2012 behrisch@users.sourceforge.net
- upstream removed Texinfo documentation
* Mon Apr  9 2012 ocefpaf@gmail.com
- Updated to 4.2
  * Fortran and C++ APIs are now in separate packages
- Removed netcdf-dependencies.patch
* Thu Apr  5 2012 jengelh@medozas.de
- Do not require valgrind on arches where it is not available
  (e.g. sparc)
* Fri Mar 16 2012 cfarrell@suse.com
- license update: SUSE-NetCDF
  Use SPDX- proprietary prefix until this license is accepted upstream by
  spdx.org
* Wed Nov 30 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Appropriate rpmgroups for shlib packages
* Tue Nov 29 2011 ocefpaf@gmail.com
- Added explicit hdf5 dependency.
- Rebuild with hdf5 1.8.8
- Some spec file clean-ups.
* Sun Jun 26 2011 ocefpaf@yahoo.com.br
- Added pkgconfig and fflags patches
- Dropped libm patch fixed upstream
- Fixed summary, license info, description
- Created doc and static packages
* Sun Jun 26 2011 ocefpaf@yahoo.com.br
- updated to 4.1.3
* Thu Jun  2 2011 ocefpaf@yahoo.com.br
- rename libnetcdf-devel to netcdf-devel as recommended by pth
* Fri Apr 29 2011 ocefpaf@yahoo.com.br
- updated to version 4.1.2
- added flag --enable-dap for OpenDap support
- updated the patches
* Tue Nov 30 2010 pth@suse.de
- Just fix the casting in px_get to avoid the type-punning warning.
- Add a man page for nc-config.
- Move nc-config and its man page to the devel package.
- Remove the dependency on netcdf from libnetcdf.
- BuildRequire pkgconfig for libnetcdf-devel.
- Declare strlcat if needed.
- Don't use __DATE__ and __TIME__ to reduce the need for recompiling.
* Tue May 19 2009 prusnak@suse.cz
- updated to 4.0.1
  * Added optional arguments to F90 API to nf90_open/create,
    nf90_create_var, and nf90_inquire_variable so that all netCDF-4
    settings may be accomplished with optional arguments, instead
    of separate function calls.
  * Added control of HDF5 chunk cache to allow for user performance
    tuning.
  * Added parallel example program in F90.
  * Changed default chunking to better handle very large variables.
  * Made contiguous the default for fixed size data sets with no
    filters.
  * Fixed bug in nc_inq_ncid; now it returns NC_ENOGRP if the named
    group is not found.
  * Fixed man pages for C and F77 so that netCDF-4 builds will
    result in man pages that document new netCDF-4 functions.
  * Added OPeNDAP support based on a new C-only implementation.
    This is enabled using --enable-dap option and requires libcurl.
    The configure script will attempt to locate libcurl, but if it
    fails, then its location must be specified by the --with-curl
    option.
  * Changed chunksizes to size_t from int.
  * Fixed fill value problem from F77 API.
  * Fixed problems in netcdf-4 files with multi-dimensional
    coordinate variables.
  * Fixed ncgen to properly handle CDL input that uses Windows line
    endings ("\r\n"), instead of getting a syntax error.
  * Added "-s" option to ncdump to display performance
    characterisitics of netCDF-4 files as special virtual attributes,
    such as _Chunking, _DeflateLevel, _Format, and _Endianness.
  * Added "-t" option to ncdump to display times in human readable
    form as strings.  Added code to interpret "calendar" attribute
    according to CF conventions, if present, in displaying
    human-readable times.
  * Added experimental version of ncgen4 capable of generating
    netcdf-4 data files and C code for creating them. In addition,
    it supports the special attributes _Format, etc.
  * Fixed Fortran 90 int64 problems.
  * Rewrote HDF5 read/write code in accordance with performance advice
    from Kent.
  * Fixed memory leaks in gets/puts of HDF5 data.
  * Fixed some broken tests for parallel I/O (i.e. MPI) builds.
  * Fixed some cross-compile problems.
  * Rewrote code which placed bogus errors on the HDF5 error stack,
    trying to open non-existant attributes and variables. Now no HDF5
    errors are seen.
  * Removed man subdirectory. Now man4 subdirectory is used for all
    builds.
  * Changed build so that users with access to parallel make can
    use it.
  * Added experimental support for accessing data through OPeNDAP
    servers using the DAP protocol (use --enable-opendap to build it).
  * Fixed ncdump bugs with array field members of compound type
    variables.  Fixed ncdump bug of assuming default fill value
    for data of type unsigned byte.
* Fri Nov 14 2008 prusnak@suse.cz
- fix wrong delete usage (delete.patch)
* Mon Sep  8 2008 prusnak@suse.cz
- move devel manpages and infopages to -devel subpackage
* Mon Sep  1 2008 prusnak@suse.cz
- disable static libraries
* Fri Aug 22 2008 schwab@suse.de
- Fix makefile dependencies.
* Wed Aug 13 2008 prusnak@suse.cz
- updated to 4.0
  * Introduced the use of HDF5 as a storage layer, which allows use
    of groups, user-defined types, multiple unlimited dimensions,
    compression, data chunking, parallel I/O, and other features
  * In ncdump and ncgen, added CDL support for UTF-8 encoding
    of characters in names and for escaped special chars in names.
    Made sure UTF-8 names are normalized using NFC rules before
    storing or comparing
  * Handle IEEE NaNs and infinities in a platform-independent way
    in ncdump output
  * Added support for ARM representation of doubles
  * Fixed bug in C++ API creating 64-bit offset files
  * Fixed bug for variables larger than 4 GB
  * Changed the configure.ac to build either 3.6.x or 4.x build
    from the same configure.ac
  * Build now checks gfortran version and handles it cleanly,
    also Portland Group in Intel fortran, with various configurations
  * A Fortran netcdf.inc file is now created at build time, based
    on the setting of --disable-v2
  * Documentation has been fixed in several places
  * Upgraded to automake 1.10, autoconf 2.62, and libtool 2.2.2
  * Includes missing Windows Visual Studio build files
  * Fixed missing include of config.h in a C++ test program
  * Fixed maintainer-clean in man directory
  * Fixed --enable-c-only and make check
  * Fixed behavior when opening a zero-length file
  * Many portability enhancements to build cleanly
    on various platforms
  * Turned on some old test programs which were not being used
    in the build
- dropped obsoleted patches:
  * missing-includes.patch (included in update)
* Thu Jan 10 2008 lrupp@suse.de
- use more macros in specfile
- added netcdf-3.6.2-missing_includes.patch
* Mon Aug  6 2007 zpetrova@suse.cz
- split to libnetcdf-4, libnetcdf-devel and netcdf package
  according to Shared library guidelines.
* Mon Jul 30 2007 zpetrova@suse.cz
-update to version 3.6.2
  - Added support for shared libraries (with configure option --enable-shared).
  - Improved performance of byte-swapping loops on little-endian platforms.
  - Added a "-k" option to ncdump and ncgen, for identifying or specifying the kind
    of netCDF file if other than "classic".
  - Made long-threatened change of type of ncbyte in C++ interface from unsigned char
    to signed char, for consistency with C interface.
  - Implemented the C++ API on the netCDF-3 C API instead of the older netCDF-2 API,
    providing automatic numeric type conversion as in the netCDF-3 C interface.
  - Modified to build correctly for gfortran.
  - Added more tests!
  - Fixed minor bugs relating to creation of very small netCDF files.
  - Added support for additional configure options
    (run configure --help for more information).
* Mon May 21 2007 ro@suse.de
- removed cfortran.doc from tarball due to "non-commercial" status
- check in specfile to make sure the file does not reappear
* Thu Oct 19 2006 zpetrova@suse.cz
- update to version 3.6.1
  - updated installation manual
  - netcdf padded small files with zero to 4096 bytes, when they
    were opened and changed. Fixed.
  - small fixes in test suite (return values, names of output files).
  - Doubled arbitrary limits on number of dimensions, variables,
    attributes, and length of names.
  - added new functions, including doc and tests.
  - correctly configure for Intel ifort Fortran compiler on Linux.
* Wed Apr 19 2006 dmueller@suse.de
- build PIC code
* Mon Jan 30 2006 zpetrova@suse.cz
- fixed permissions of libraries, man pages and header files (#131552)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 zpetrova@suse.cz
- update to netcdf-3.6.0-p1
* Thu Sep 29 2005 zpetrova@suse.cz
- add -fno-strict-aliasing
* Tue Jan 11 2005 didge@suse.de
- Updated to new version
- changed URL to the new one
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Fri Apr 23 2004 didge@suse.de
- Updated to new version 3.5.1
- Fixed strict aliasing problem
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue May 13 2003 nashif@suse.de
- added defattr to file list
* Mon Mar 10 2003 nashif@suse.de
- fixed #24975: Build c++ library
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue May 21 2002 ro@suse.de
- complete libdir usage
* Fri Mar  1 2002 nashif@suse.de
- use macro _libdir, fix for s390x build
* Fri Apr 20 2001 nashif@suse.de
- Update to version 3.5.0
- fixed %%files
* Fri Mar 23 2001 nashif@suse.de
- Spec cleanups
- Removed autospec from neededforbuild
* Wed Oct 11 2000 nashif@suse.de
- Use BuildRoot
- Change maintainership to nashif@suse.de
* Tue Jun  6 2000 marquardt@suse.de
- added fortran interface
* Mon May  8 2000 freitag@suse.de
- initial build of version 3.4
